@@ -31,8 +31,9 @@
 #include "nautilus-directory.h"
 #include "nautilus-file-attributes.h"
 #include "nautilus-file.h"
-#include "nautilus-metadata.h"
 #include "nautilus-file-utilities.h"
+#include "nautilus-global-preferences.h"
+#include "nautilus-metadata.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-stock-dialogs.h>
@@ -40,7 +41,6 @@
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
@@ -231,12 +231,13 @@ nautilus_link_local_get_link_type (const char *path)
 }
 
 char *
-nautilus_link_get_link_uri_given_file_contents (const char *file_contents,
+nautilus_link_get_link_uri_given_file_contents (const char *uri,
+						const char *file_contents,
 						int file_size)
 {
 	switch (get_link_style_for_data (file_contents, file_size)) {
 	case desktop:
-		return nautilus_link_desktop_file_get_link_uri_given_file_contents (file_contents, file_size);
+		return nautilus_link_desktop_file_get_link_uri_given_file_contents (uri, file_contents, file_size);
 	case historical:
 		return nautilus_link_historical_get_link_uri_given_file_contents (file_contents, file_size);
 	default:
@@ -245,12 +246,13 @@ nautilus_link_get_link_uri_given_file_contents (const char *file_contents,
 }
 
 char *
-nautilus_link_get_link_name_given_file_contents (const char *file_contents,
+nautilus_link_get_link_name_given_file_contents (const char *uri,
+						 const char *file_contents,
 						 int file_size)
 {
 	switch (get_link_style_for_data (file_contents, file_size)) {
 	case desktop:
-		return nautilus_link_desktop_file_get_link_name_given_file_contents (file_contents, file_size);
+		return nautilus_link_desktop_file_get_link_name_given_file_contents (uri, file_contents, file_size);
 	case historical:
 		return NULL;
 	default:
@@ -259,12 +261,13 @@ nautilus_link_get_link_name_given_file_contents (const char *file_contents,
 }
 
 char *
-nautilus_link_get_link_icon_given_file_contents (const char *file_contents,
-						int file_size)
+nautilus_link_get_link_icon_given_file_contents (const char *uri,
+						 const char *file_contents,
+						 int file_size)
 {
 	switch (get_link_style_for_data (file_contents, file_size)) {
 	case desktop:
-		return nautilus_link_desktop_file_get_link_icon_given_file_contents (file_contents, file_size);
+		return nautilus_link_desktop_file_get_link_icon_given_file_contents (uri, file_contents, file_size);
 	case historical:
 		return nautilus_link_historical_get_link_icon_given_file_contents (file_contents, file_size);
 	default:
@@ -275,50 +278,43 @@ nautilus_link_get_link_icon_given_file_contents (const char *file_contents,
 gboolean
 nautilus_link_local_is_volume_link (const char *path)
 {
-	switch (get_link_style_for_local_file (path)) {
-	case desktop:
-		return nautilus_link_desktop_file_local_is_volume_link (path);
-	case historical:
-		return nautilus_link_historical_local_is_volume_link (path);
-	default:
-		return FALSE;
-	}
+	return (nautilus_link_local_get_link_type (path) == NAUTILUS_LINK_MOUNT);
 }
 
 gboolean
 nautilus_link_local_is_home_link (const char *path)
 {
-	switch (get_link_style_for_local_file (path)) {
-	case desktop:
-		return nautilus_link_desktop_file_local_is_home_link (path);
-	case historical:
-		return nautilus_link_historical_local_is_home_link (path);
-	default:
-		return FALSE;
-	}
+	return (nautilus_link_local_get_link_type (path) == NAUTILUS_LINK_HOME);
 }
 
 gboolean
 nautilus_link_local_is_trash_link (const char *path)
 {
-	switch (get_link_style_for_local_file (path)) {
-	case desktop:
-		return nautilus_link_desktop_file_local_is_trash_link (path);
-	case historical:
-		return nautilus_link_historical_local_is_trash_link (path);
-	default:
-		return FALSE;
-	}
+	return (nautilus_link_local_get_link_type (path) == NAUTILUS_LINK_TRASH);
 }
 
-#if GNOME2_CONVERSION_COMPLETE
+gboolean
+nautilus_link_local_is_special_link (const char *path)
+{
+	switch (nautilus_link_local_get_link_type (path)) {
+	case NAUTILUS_LINK_HOME:
+		if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
+ 			return FALSE;
+ 		}
+	case NAUTILUS_LINK_TRASH:
+	case NAUTILUS_LINK_MOUNT:
+		return TRUE;
+	case NAUTILUS_LINK_GENERIC:
+		return FALSE;
+	}
+
+	return FALSE;
+}
 
 void
-nautilus_link_local_create_from_gnome_entry (GnomeDesktopEntry *entry,
+nautilus_link_local_create_from_gnome_entry (GnomeDesktopItem *item,
 					     const char *dest_path,
 					     const GdkPoint *position)
 {
-	nautilus_link_desktop_file_local_create_from_gnome_entry (entry, dest_path, position);
+	nautilus_link_desktop_file_local_create_from_gnome_entry (item, dest_path, position);
 }
-
-#endif
