@@ -64,7 +64,7 @@ static gboolean thumbnail_in_progress;
 /* id of timeout task for making thumbnails */
 static int thumbnail_timeout_id;
 
-static int make_thumbnails (gpointer data);
+static gboolean make_thumbnails (gpointer data);
 
 /* utility to test whether a file exists using vfs */
 static gboolean
@@ -104,25 +104,9 @@ uri_is_local (const char *uri)
 static gboolean
 prefer_global_thumbnails_location (const char *image_uri)
 {
-	static int public_metadata_preference;
-	static gboolean public_metadata_preference_registered;
-
-	if (!public_metadata_preference_registered) {
-		eel_preferences_add_auto_enum (NAUTILUS_PREFERENCES_USE_PUBLIC_METADATA,
-					       &public_metadata_preference);
-		public_metadata_preference_registered = TRUE;
-	}
-
-	if (public_metadata_preference == NAUTILUS_SPEED_TRADEOFF_NEVER) {
-		return TRUE;
-	}
-
-	if (public_metadata_preference == NAUTILUS_SPEED_TRADEOFF_ALWAYS) {
-		return FALSE;
-	}
-
-	g_assert (public_metadata_preference == NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY);
-	return !uri_is_local (image_uri);
+	/* We always prefer global thumbnails since we removed public
+	   metadata. */
+	return TRUE;
 }
 
 /* this functions looks for a password in a uri and changes it for 6 'x' */
@@ -365,12 +349,12 @@ nautilus_get_thumbnail_uri (NautilusFile *file)
 	file_mtime = INVALID_MTIME;
 	
 	/* if the thumbnail file already exists locally, simply return the uri */
-	
 	/* note: thumbnail_uri is always local here, so it's not a disaster that we make a synchronous call below.
 	   Eventually, we'll want to do everything asynchronously, when we have time to restructure the thumbnail engine */
 	if (vfs_file_exists (thumbnail_uri)) {
-		
 		/* see if the file changed since it was thumbnailed by comparing the modification time */
+		/* Note: There may be a file there with the wrong mtime, but we can't write to the directory.
+		 *       Make sure you don't loop trying to read this after having created a global one */
 		remake_thumbnail = files_have_different_mtime (file_uri, thumbnail_uri, &file_mtime);
 		
 		/* if the file hasn't changed, return the thumbnail uri */
@@ -386,27 +370,25 @@ nautilus_get_thumbnail_uri (NautilusFile *file)
 	}
 	
 	/* now try it globally */
-	if (!remake_thumbnail) {
-		g_free (thumbnail_uri);
-		thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, FALSE, TRUE);
+	g_free (thumbnail_uri);
+	thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, FALSE, TRUE);
 		
-		/* if the thumbnail file already exists in the common area,  return that uri, */
-		/* the uri is guaranteed to be local */
-		if (vfs_file_exists (thumbnail_uri)) {
+	/* if the thumbnail file already exists in the common area,  return that uri, */
+	/* the uri is guaranteed to be local */
+	if (vfs_file_exists (thumbnail_uri)) {
 		
-			/* see if the file changed since it was thumbnailed by comparing the modification time */
-			remake_thumbnail = files_have_different_mtime (file_uri, thumbnail_uri, &file_mtime);
+		/* see if the file changed since it was thumbnailed by comparing the modification time */
+		remake_thumbnail = files_have_different_mtime (file_uri, thumbnail_uri, &file_mtime);
 		
-			/* if the file hasn't changed, return the thumbnail uri */
-			if (!remake_thumbnail) {
-				g_free (file_uri);
-				return thumbnail_uri;
-			} else {
-				nautilus_icon_factory_remove_by_uri (thumbnail_uri);
-
-				/* the uri is guaranteed to be local */
-				gnome_vfs_unlink (thumbnail_uri);
-			}
+		/* if the file hasn't changed, return the thumbnail uri */
+		if (!remake_thumbnail) {
+			g_free (file_uri);
+			return thumbnail_uri;
+		} else {
+			nautilus_icon_factory_remove_by_uri (thumbnail_uri);
+			
+			/* the uri is guaranteed to be local */
+			gnome_vfs_unlink (thumbnail_uri);
 		}
 	}
 	
@@ -414,7 +396,7 @@ nautilus_get_thumbnail_uri (NautilusFile *file)
 	g_free (thumbnail_uri);
 	local_flag = TRUE;
 	thumbnail_uri = make_thumbnail_uri (file_uri, TRUE, local_flag, TRUE);
-				
+
 	/* FIXME bugzilla.gnome.org 43137: more potentially losing
 	   synch I/O - this could be remote */
 
@@ -433,6 +415,7 @@ nautilus_get_thumbnail_uri (NautilusFile *file)
 		g_free (thumbnail_uri);
 		local_flag = FALSE;
 		thumbnail_uri = make_thumbnail_uri (file_uri, TRUE, local_flag, TRUE);
+
 		/* this is guaranteed to be local, so synch I/O can be tolerated here */
 		result = gnome_vfs_make_directory (thumbnail_uri, THUMBNAIL_DIR_PERMISSIONS);	
 	}
@@ -461,8 +444,8 @@ nautilus_get_thumbnail_uri (NautilusFile *file)
 		}
 	
 		if (thumbnail_timeout_id == 0) {
-			thumbnail_timeout_id = gtk_timeout_add
-				(400, make_thumbnails, NULL);
+			thumbnail_timeout_id = g_idle_add_full
+				(G_PRIORITY_LOW, make_thumbnails, NULL, NULL);
 		}
 	}
 	
@@ -572,16 +555,16 @@ check_for_thumbnails (void)
 }
 
 /* make_thumbnails is invoked periodically as a timer task to launch a task to make thumbnails */
-static int
+static gboolean
 make_thumbnails (gpointer data)
 {
 	NautilusThumbnailInfo *info;
 	GList *next_thumbnail = thumbnails;
 	GdkPixbuf *scaled_image;
-	
+
 	/* if the queue is empty, there's nothing more to do */
 	if (next_thumbnail == NULL) {
-		gtk_timeout_remove (thumbnail_timeout_id);
+		g_source_remove (thumbnail_timeout_id);
 		thumbnail_timeout_id = 0;
 		return FALSE;
 	}
@@ -676,7 +659,7 @@ make_thumbnails (gpointer data)
 				 * but we're lame.
 				 */
 				file_info->atime = info->original_file_mtime;
-				
+
 				gnome_vfs_set_file_info (new_thumbnail_uri,
 							 file_info,
 							 GNOME_VFS_SET_FILE_INFO_TIME);
