@@ -26,12 +26,15 @@
 #include "fm-list-model.h"
 
 #include <string.h>
+#include <eel/eel-gtk-macros.h>
 #include <gtk/gtktreednd.h>
 #include <gtk/gtktreesortable.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 
 #define G_SLIST(x) ((GSList *) x)
 
+static GObjectClass *parent_class;
+
 struct FMListModelDetails {
 	GSList *files;
 	GSList *tail;
@@ -50,14 +53,21 @@ typedef struct {
 	int sort_column_id;
 } AttributeEntry;
 
+/*
+ * Do not change the order of the type and size attributes, they 
+ * have to be in this order so that the column_id to attribute mapping
+ * works. This is needed to store the sorting preferences. This duplicate
+ * entry is here to allow the ordering by icon (i think...)
+ */
+
 static const AttributeEntry attributes[] = {
 	{ "name", FM_LIST_MODEL_NAME_COLUMN },
-	{ "icon", FM_LIST_MODEL_TYPE_COLUMN },
+	{ "type", FM_LIST_MODEL_TYPE_COLUMN },
 #ifdef GNOME2_CONVERSION_COMPLETE
 	{ "emblems", FM_LIST_MODEL_EMBLEMS_COLUMN },
 #endif
 	{ "size", FM_LIST_MODEL_SIZE_COLUMN },
-	{ "type", FM_LIST_MODEL_TYPE_COLUMN },
+	{ "icon", FM_LIST_MODEL_TYPE_COLUMN },
 	{ "date_modified", FM_LIST_MODEL_DATE_MODIFIED_COLUMN },
 };
 
@@ -84,7 +94,13 @@ fm_list_model_get_column_type (GtkTreeModel *tree_model, int index)
 	case FM_LIST_MODEL_TYPE_COLUMN:
 	case FM_LIST_MODEL_DATE_MODIFIED_COLUMN:
 		return G_TYPE_STRING;
-	case FM_LIST_MODEL_ICON_COLUMN:
+	case FM_LIST_MODEL_SMALLEST_ICON_COLUMN:
+	case FM_LIST_MODEL_SMALLER_ICON_COLUMN:
+	case FM_LIST_MODEL_SMALL_ICON_COLUMN:
+	case FM_LIST_MODEL_STANDARD_ICON_COLUMN:
+	case FM_LIST_MODEL_LARGE_ICON_COLUMN:
+	case FM_LIST_MODEL_LARGER_ICON_COLUMN:
+	case FM_LIST_MODEL_LARGEST_ICON_COLUMN:
 		return GDK_TYPE_PIXBUF;
 	case FM_LIST_MODEL_FILE_NAME_IS_EDITABLE_COLUMN:
 		return G_TYPE_BOOLEAN;
@@ -148,7 +164,6 @@ fm_list_model_get_path (GtkTreeModel *tree_model, GtkTreeIter *iter)
 	return path;
 }
 
-
 static void
 fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column, GValue *value)
 {
@@ -156,7 +171,9 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 	NautilusFile *file;
 	char *str;
 	GdkPixbuf *icon;
-	
+	int icon_size;
+	NautilusZoomLevel zoom_level;
+
 	model = (FMListModel *)tree_model;
 
 	g_return_if_fail (model->details->stamp == iter->stamp);
@@ -175,10 +192,18 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 		str = nautilus_file_get_string_attribute_with_default (file, "name");
 		g_value_set_string_take_ownership (value, str);
 		break;
-	case FM_LIST_MODEL_ICON_COLUMN:
+	case FM_LIST_MODEL_SMALLEST_ICON_COLUMN:
+	case FM_LIST_MODEL_SMALLER_ICON_COLUMN:
+	case FM_LIST_MODEL_SMALL_ICON_COLUMN:
+	case FM_LIST_MODEL_STANDARD_ICON_COLUMN:
+	case FM_LIST_MODEL_LARGE_ICON_COLUMN:
+	case FM_LIST_MODEL_LARGER_ICON_COLUMN:
+	case FM_LIST_MODEL_LARGEST_ICON_COLUMN:
 		g_value_init (value, GDK_TYPE_PIXBUF);
 
-		icon = nautilus_icon_factory_get_pixbuf_for_file (file, NULL, NAUTILUS_ICON_SIZE_SMALLER);
+		zoom_level = fm_list_model_get_zoom_level_from_column_id (column);
+		icon_size = nautilus_get_icon_size_for_zoom_level (zoom_level);
+		icon = nautilus_icon_factory_get_pixbuf_for_file (file, NULL, icon_size);
 		g_value_set_object (value, icon);
 		g_object_unref (icon);
 		break;
@@ -425,6 +450,7 @@ fm_list_model_sort (FMListModel *model)
 	path = gtk_tree_path_new ();
 	iter.stamp = model->details->stamp;
 	iter.user_data = NULL;
+
 	gtk_tree_model_rows_reordered (GTK_TREE_MODEL (model),
 				       path, NULL, new_order);
 	gtk_tree_path_free (path);
@@ -698,13 +724,28 @@ fm_list_model_get_sort_column_id_from_attribute (const char *attribute)
 
 	for (i = 0; i < G_N_ELEMENTS (attributes); i++) {
 		if (strcmp (attributes[i].attribute_name, attribute) == 0) {
-			return i;
+			return attributes[i].sort_column_id;
 		}
 	}
 
 	return -1;
 }
 
+char *
+fm_list_model_get_attribute_from_sort_column_id (int sort_column_id)
+{
+	guint i;
+
+	for (i = 0; i < G_N_ELEMENTS (attributes); i++) {
+		if (attributes[i].sort_column_id == sort_column_id) {
+			return g_strdup (attributes[i].attribute_name);
+		}
+	}
+
+	g_warning ("unknown sort column id: %d", sort_column_id);
+	return g_strdup ("name");
+}
+
 int
 fm_list_model_get_sort_column_id_from_sort_type (NautilusFileSortType sort_type)
 {
@@ -727,6 +768,64 @@ fm_list_model_get_sort_column_id_from_sort_type (NautilusFileSortType sort_type)
 	g_return_val_if_reached (-1);
 }
 
+NautilusZoomLevel
+fm_list_model_get_zoom_level_from_column_id (int column)
+{
+	switch (column) {
+	case FM_LIST_MODEL_SMALLEST_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_SMALLEST;
+	case FM_LIST_MODEL_SMALLER_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_SMALLER;
+	case FM_LIST_MODEL_SMALL_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_SMALL;
+	case FM_LIST_MODEL_STANDARD_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_STANDARD;
+	case FM_LIST_MODEL_LARGE_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_LARGE;
+	case FM_LIST_MODEL_LARGER_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_LARGER;
+	case FM_LIST_MODEL_LARGEST_ICON_COLUMN:
+		return NAUTILUS_ZOOM_LEVEL_LARGEST;
+	}
+
+	g_return_val_if_reached (NAUTILUS_ZOOM_LEVEL_STANDARD);
+}
+
+int
+fm_list_model_get_column_id_from_zoom_level (NautilusZoomLevel zoom_level)
+{
+	switch (zoom_level) {
+	case NAUTILUS_ZOOM_LEVEL_SMALLEST:
+		return FM_LIST_MODEL_SMALLEST_ICON_COLUMN;
+	case NAUTILUS_ZOOM_LEVEL_SMALLER:
+		return FM_LIST_MODEL_SMALLER_ICON_COLUMN;
+	case NAUTILUS_ZOOM_LEVEL_SMALL:
+		return FM_LIST_MODEL_SMALL_ICON_COLUMN;
+	case NAUTILUS_ZOOM_LEVEL_STANDARD:
+		return FM_LIST_MODEL_STANDARD_ICON_COLUMN;
+	case NAUTILUS_ZOOM_LEVEL_LARGE:
+		return FM_LIST_MODEL_LARGE_ICON_COLUMN;
+	case NAUTILUS_ZOOM_LEVEL_LARGER:
+		return FM_LIST_MODEL_LARGER_ICON_COLUMN;
+	case NAUTILUS_ZOOM_LEVEL_LARGEST:
+		return FM_LIST_MODEL_LARGEST_ICON_COLUMN;
+	}
+
+	g_return_val_if_reached (FM_LIST_MODEL_STANDARD_ICON_COLUMN);
+}
+
+static void
+fm_list_model_finalize (GObject *object)
+{
+	FMListModel *model;
+
+	model = FM_LIST_MODEL (object);
+
+	g_free (model->details);
+	
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+}
+
 static void
 fm_list_model_init (FMListModel *model)
 {
@@ -738,6 +837,12 @@ fm_list_model_init (FMListModel *model)
 static void
 fm_list_model_class_init (FMListModelClass *klass)
 {
+	GObjectClass *object_class;
+
+	object_class = (GObjectClass *)klass;
+	parent_class = g_type_class_peek_parent (klass);
+
+	object_class->finalize = fm_list_model_finalize;
 }
 
 static void
