@@ -31,7 +31,6 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
 #include <eel/eel-labeled-image.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
@@ -43,6 +42,7 @@
 #include <gtk/gtkentry.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkhbbox.h>
 #include <gtk/gtkhseparator.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
@@ -51,9 +51,11 @@
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtksignal.h>
+#include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
+#include <libgnome/gnome-macros.h>
 #include <libgnomeui/gnome-dialog.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -131,12 +133,14 @@ typedef struct {
 
 enum {
 	TARGET_URI_LIST,
-	TARGET_GNOME_URI_LIST
+	TARGET_GNOME_URI_LIST,
+	TARGET_RESET_BACKGROUND
 };
 
 static GtkTargetEntry target_table[] = {
 	{ "text/uri-list",  0, TARGET_URI_LIST },
-	{ "x-special/gnome-icon-list",  0, TARGET_GNOME_URI_LIST }
+	{ "x-special/gnome-icon-list",  0, TARGET_GNOME_URI_LIST },
+	{ "x-special/gnome-reset-background", 0, TARGET_RESET_BACKGROUND }
 };
 
 #define ERASE_EMBLEM_FILENAME	"erase.png"
@@ -145,10 +149,6 @@ static GtkTargetEntry target_table[] = {
 #define STANDARD_EMBLEM_HEIGHT			52
 #define EMBLEM_LABEL_SPACING			2
 
-static void real_destroy                          (GtkObject               *object);
-static void real_finalize                         (GObject                 *object);
-static void fm_properties_window_class_init       (FMPropertiesWindowClass *class);
-static void fm_properties_window_init             (FMPropertiesWindow      *window);
 static void create_properties_window_callback     (NautilusFile		   *file,
 						   gpointer                 data);
 static void cancel_group_change_callback          (gpointer                 callback_data);
@@ -166,23 +166,8 @@ static void remove_pending_file                   (StartupData             *data
 						   gboolean                 cancel_timed_wait,
 						   gboolean                 cancel_destroy_handler);
 
-EEL_CLASS_BOILERPLATE (FMPropertiesWindow, fm_properties_window, GTK_TYPE_WINDOW)
-
-static void
-fm_properties_window_class_init (FMPropertiesWindowClass *class)
-{
-	G_OBJECT_CLASS (class)->finalize = real_finalize;
-	
-	GTK_OBJECT_CLASS (class)->destroy = real_destroy;
-}
-
-static void
-fm_properties_window_init (FMPropertiesWindow *window)
-{
-	window->details = g_new0 (FMPropertiesWindowDetails, 1);
-
-	eel_gtk_window_set_up_close_accelerator (GTK_WINDOW (window));
-}
+GNOME_CLASS_BOILERPLATE (FMPropertiesWindow, fm_properties_window,
+			 GtkWindow, GTK_TYPE_WINDOW)
 
 typedef struct {
 	NautilusFile *file;
@@ -288,6 +273,19 @@ uri_is_local_image (const char *uri)
 	return TRUE;
 }
 
+static void
+reset_icon (FMPropertiesWindow *properties_window)
+{
+	NautilusFile *file;
+	
+	file = properties_window->details->original_file;
+	
+	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_CUSTOM_ICON, NULL, NULL);
+	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_ICON_SCALE, NULL, NULL);
+	
+	gtk_widget_set_sensitive (properties_window->details->remove_image_button, FALSE);
+}
+
 static void  
 fm_properties_window_drag_data_received (GtkWidget *widget, GdkDragContext *context,
 					 int x, int y,
@@ -299,37 +297,43 @@ fm_properties_window_drag_data_received (GtkWidget *widget, GdkDragContext *cont
 	GtkImage *image;
  	GtkWindow *window; 
 
-	uris = g_strsplit (selection_data->data, "\r\n", 0);
-	exactly_one = uris[0] != NULL && uris[1] == NULL;
-
 	image = GTK_IMAGE (widget);
  	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (image)));
 
+	if (info == TARGET_RESET_BACKGROUND) {
+		reset_icon (FM_PROPERTIES_WINDOW (window));
+		
+		return;
+	}
+	
+	uris = g_strsplit (selection_data->data, "\r\n", 0);
+	exactly_one = uris[0] != NULL && (uris[1] == NULL || uris[1][0] == '\0');
+
 
 	if (!exactly_one) {
-		eel_show_error_dialog (
-				       _("You can't assign more than one custom icon at a time! "
-					 "Please drag just one image to set a custom icon."), 
-				       _("More Than One Image"),
-				       window);
+		eel_show_error_dialog
+			(_("You can't assign more than one custom icon at a time! "
+			   "Please drag just one image to set a custom icon."), 
+			 _("More Than One Image"),
+			 window);
 	} else {		
 		if (uri_is_local_image (uris[0])) {			
 			set_icon_callback (gnome_vfs_get_local_path_from_uri (uris[0]), 
 					   FM_PROPERTIES_WINDOW (window));
 		} else {	
 			if (eel_is_remote_uri (uris[0])) {
-				eel_show_error_dialog (
-						       _("The file that you dropped is not local.  "
-							 "You can only use local images as custom icons."), 
-						       _("Local Images Only"),
-						       window);
+				eel_show_error_dialog
+					(_("The file that you dropped is not local.  "
+					   "You can only use local images as custom icons."), 
+					 _("Local Images Only"),
+					 window);
 				
 			} else {
-				eel_show_error_dialog (
-						       _("The file that you dropped is not an image.  "
-							 "You can only use local images as custom icons."),
-						       _("Images Only"),
-						       window);
+				eel_show_error_dialog
+					(_("The file that you dropped is not an image.  "
+					   "You can only use local images as custom icons."),
+					 _("Images Only"),
+					 window);
 			}
 		}		
 	}
@@ -352,8 +356,8 @@ create_image_widget_for_file (NautilusFile *file)
 			   target_table, G_N_ELEMENTS (target_table),
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
 
-	g_signal_connect(image, "drag_data_received",
-			 G_CALLBACK (fm_properties_window_drag_data_received), NULL);
+	g_signal_connect (image, "drag_data_received",
+			  G_CALLBACK (fm_properties_window_drag_data_received), NULL);
 
 
 	gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);
@@ -361,10 +365,8 @@ create_image_widget_for_file (NautilusFile *file)
 	g_object_unref (pixbuf);
 
 	nautilus_file_ref (file);
-	g_object_set_data_full (G_OBJECT (image),
-				"nautilus_file",
-				file,
-				(GtkDestroyNotify) nautilus_file_unref);
+	g_object_set_data_full (G_OBJECT (image), "nautilus_file",
+				file, (GDestroyNotify) nautilus_file_unref);
 
 	/* React to icon theme changes. */
 	g_signal_connect_object (nautilus_icon_factory_get (),
@@ -373,8 +375,7 @@ create_image_widget_for_file (NautilusFile *file)
 				 image, G_CONNECT_SWAPPED);
 
 	/* Name changes can also change icon (since name is determined by MIME type) */
-	g_signal_connect_object (file,
-				 "changed",
+	g_signal_connect_object (file, "changed",
 				 G_CALLBACK (update_properties_window_icon),
 				 image, G_CONNECT_SWAPPED);
 	return image;
@@ -642,8 +643,7 @@ value_field_update_internal (GtkLabel *label,
 	attribute_value = nautilus_file_get_string_attribute_with_default (file, attribute_name);
 
 	if (ellipsize_text) {
-		eel_ellipsizing_label_set_text (EEL_ELLIPSIZING_LABEL (label), 
-						     attribute_value);
+		eel_ellipsizing_label_set_text (EEL_ELLIPSIZING_LABEL (label), attribute_value);
 	} else {
 		gtk_label_set_text (label, attribute_value);
 	}
@@ -734,10 +734,8 @@ attach_value_field_internal (GtkTable *table,
 	}
 
 	/* Stash a copy of the file attribute name in this field for the callback's sake. */
-	g_object_set_data_full (G_OBJECT (value_field),
-				"file_attribute",
-				g_strdup (file_attribute_name),
-				g_free);
+	g_object_set_data_full (G_OBJECT (value_field), "file_attribute",
+				g_strdup (file_attribute_name), g_free);
 
 	/* Fill in the value. */
 	if (ellipsize_text) {
@@ -747,8 +745,7 @@ attach_value_field_internal (GtkTable *table,
 	}
 
 	/* Connect to signal to update value when file changes. */
-	g_signal_connect_object (file,
-				 "changed",
+	g_signal_connect_object (file, "changed",
 				 ellipsize_text
 				 ? G_CALLBACK (ellipsizing_value_field_update)
 				 : G_CALLBACK (value_field_update),
@@ -829,7 +826,7 @@ create_group_menu_item (NautilusFile *file, const char *group_name)
 						 "activate",
 						 G_CALLBACK (activate_group_callback),
 						 file_name_pair_new (file, group_name),
-						 (GtkDestroyNotify)file_name_pair_free);
+						 (GDestroyNotify)file_name_pair_free);
 
 	return menu_item;
 }
@@ -928,8 +925,7 @@ attach_group_menu (GtkTable *table,
 	synch_groups_menu (option_menu, file);
 
 	/* Connect to signal to update menu when file changes. */
-	g_signal_connect_object (file,
-				 "changed",
+	g_signal_connect_object (file, "changed",
 				 G_CALLBACK (synch_groups_menu),
 				 option_menu, G_CONNECT_SWAPPED);	
 }	
@@ -1002,7 +998,7 @@ create_owner_menu_item (NautilusFile *file, const char *user_name)
 						 "activate",
 						 G_CALLBACK (activate_owner_callback),
 						 file_name_pair_new (file, name_array[0]),
-						 (GtkDestroyNotify)file_name_pair_free);
+						 (GDestroyNotify)file_name_pair_free);
 	g_strfreev (name_array);
 	return menu_item;
 }
@@ -1075,8 +1071,7 @@ attach_owner_menu (GtkTable *table,
 	synch_user_menu (option_menu, file);
 
 	/* Connect to signal to update menu when file changes. */
-	g_signal_connect_object (file,
-				 "changed",
+	g_signal_connect_object (file, "changed",
 				 G_CALLBACK (synch_user_menu),
 				 option_menu, G_CONNECT_SWAPPED);	
 }
@@ -1568,10 +1563,8 @@ create_basic_page (FMPropertiesWindow *window)
 				   
 	/* Attach parameters and signal handler. */
 	nautilus_file_ref (original_file);
-	g_object_set_data_full (G_OBJECT (name_field),
-				"nautilus_file",
-				original_file,
-				(GtkDestroyNotify) nautilus_file_unref);
+	g_object_set_data_full (G_OBJECT (name_field),"nautilus_file",
+				original_file, (GDestroyNotify) nautilus_file_unref);
 
 	/* Update name field initially before hooking up changed signal. */
 	name_field_update_to_match_file (NAUTILUS_ENTRY (name_field));
@@ -1590,13 +1583,10 @@ create_basic_page (FMPropertiesWindow *window)
 	nautilus_undo_editable_set_undo_key (GTK_EDITABLE (name_field), TRUE);
 #endif
 
-	g_signal_connect (name_field, "focus_out_event",
-      	              	    G_CALLBACK (name_field_focus_out),
-                            window);
-                      			    
-	g_signal_connect (name_field, "activate",
-      	              	    G_CALLBACK (name_field_activate),
-                            window);
+	g_signal_connect_object (name_field, "focus_out_event",
+				 G_CALLBACK (name_field_focus_out), window, 0);                      			    
+	g_signal_connect_object (name_field, "activate",
+				 G_CALLBACK (name_field_activate), window, 0);
 
         /* Start with name field selected, if it's sensitive. */
         if (GTK_WIDGET_SENSITIVE (name_field)) {
@@ -1645,13 +1635,13 @@ create_basic_page (FMPropertiesWindow *window)
 		gtk_widget_show (temp_button);
 		gtk_box_pack_start (GTK_BOX (button_box), temp_button, FALSE, FALSE, 4);  
 
-		g_signal_connect(temp_button, "clicked", G_CALLBACK (select_image_button_callback), window);
+		g_signal_connect_object (temp_button, "clicked", G_CALLBACK (select_image_button_callback), window, 0);
 	 	
 	 	temp_button = gtk_button_new_with_mnemonic (_("_Remove Custom Icon"));
 		gtk_widget_show (temp_button);
 		gtk_box_pack_start (GTK_BOX(button_box), temp_button, FALSE, FALSE, 4);  
 
-	 	g_signal_connect (temp_button, "clicked", G_CALLBACK (remove_image_button_callback), window);
+	 	g_signal_connect_object (temp_button, "clicked", G_CALLBACK (remove_image_button_callback), window, 0);
 
 		window->details->remove_image_button = temp_button;
 		
@@ -1663,14 +1653,6 @@ create_basic_page (FMPropertiesWindow *window)
 	}
 }
 
-static void
-remove_default_viewport_shadow (GtkViewport *viewport)
-{
-	g_return_if_fail (GTK_IS_VIEWPORT (viewport));
-	
-	gtk_viewport_set_shadow_type (viewport, GTK_SHADOW_NONE);
-}
-
 static void
 create_emblems_page (FMPropertiesWindow *window)
 {
@@ -1684,30 +1666,12 @@ create_emblems_page (FMPropertiesWindow *window)
 	file = window->details->target_file;
 
 	/* The emblems wrapped table */
-	emblems_table = eel_wrap_table_new (TRUE);
+	scroller = eel_scrolled_wrap_table_new (TRUE, &emblems_table);
 
-	gtk_widget_show (emblems_table);
 	gtk_container_set_border_width (GTK_CONTAINER (emblems_table), GNOME_PAD);
 	
-	scroller = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroller),
-					GTK_POLICY_NEVER,
-					GTK_POLICY_AUTOMATIC);
-
-	/* Viewport */
- 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scroller), 
- 					       emblems_table);
 	gtk_widget_show (scroller);
 
-	/* Get rid of default lowered shadow appearance. 
-	 * This must be done after the widget is realized, due to
-	 * an apparent bug in gtk_viewport_set_shadow_type.
-	 */
-	g_signal_connect (GTK_BIN (scroller)->child, 
-			  "realize", 
-			  G_CALLBACK (remove_default_viewport_shadow),
-			  NULL);
-
 	gtk_notebook_append_page (window->details->notebook, 
 				  scroller, gtk_label_new (_("Emblems")));
 	
@@ -1742,30 +1706,23 @@ create_emblems_page (FMPropertiesWindow *window)
 		g_object_unref (pixbuf);
 
 		/* Attach parameters and signal handler. */
-		g_object_set_data_full (G_OBJECT (button),
-					"nautilus_property_name",
-					emblem_name,
-					g_free);
+		g_object_set_data_full (G_OBJECT (button), "nautilus_property_name",
+					emblem_name, g_free);
 				     
 		nautilus_file_ref (file);
-		g_object_set_data_full (G_OBJECT (button),
-					"nautilus_file",
-					file,
-					(GtkDestroyNotify) nautilus_file_unref);
+		g_object_set_data_full (G_OBJECT (button), "nautilus_file",
+					file, (GDestroyNotify) nautilus_file_unref);
 		
-		g_signal_connect (button,
-				    "toggled",
-				    G_CALLBACK (property_button_toggled),
-				    NULL);
+		g_signal_connect (button, "toggled",
+				  G_CALLBACK (property_button_toggled), NULL);
 
 		/* Set initial state of button. */
 		property_button_update (GTK_TOGGLE_BUTTON (button));
 
 		/* Update button when file changes in future. */
-		g_signal_connect_object (file,
-					 "changed",
-					 G_CALLBACK (property_button_update),
-					 button, G_CONNECT_SWAPPED);
+		g_signal_connect_object (file, "changed",
+					 G_CALLBACK (property_button_update), button,
+					 G_CONNECT_SWAPPED);
 
 		gtk_container_add (GTK_CONTAINER (emblems_table), button);
 	}
@@ -1798,7 +1755,7 @@ static void
 update_permissions_check_button_state (GtkWidget *check_button, NautilusFile *file)
 {
 	GnomeVFSFilePermissions file_permissions, permission;
-	guint toggled_signal_id;
+	gulong toggled_signal_id;
 
 	g_assert (GTK_IS_CHECK_BUTTON (check_button));
 	g_assert (NAUTILUS_IS_FILE (file));
@@ -1809,11 +1766,11 @@ update_permissions_check_button_state (GtkWidget *check_button, NautilusFile *fi
 	
 	g_assert (nautilus_file_can_get_permissions (file));
 
-	toggled_signal_id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (check_button),
-						 		  "toggled_signal_id"));
+	toggled_signal_id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (check_button),
+								"toggled_signal_id"));
 	permission = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (check_button),
-							   "permission"));
-	g_assert (toggled_signal_id > 0);
+							 "permission"));
+	g_assert (toggled_signal_id != 0);
 	g_assert (permission != 0);
 
 	file_permissions = nautilus_file_get_permissions (file);
@@ -1821,12 +1778,10 @@ update_permissions_check_button_state (GtkWidget *check_button, NautilusFile *fi
 				  nautilus_file_can_set_permissions (file));
 
 	/* Don't react to the "toggled" signal here to avoid recursion. */
-	g_signal_handler_block (check_button,
-				toggled_signal_id);
+	g_signal_handler_block (check_button, toggled_signal_id);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
 				      (file_permissions & permission) != 0);
-	g_signal_handler_unblock (check_button,
-				  toggled_signal_id);
+	g_signal_handler_unblock (check_button, toggled_signal_id);
 }
 
 static void
@@ -1874,26 +1829,23 @@ set_up_permissions_checkbox (GtkWidget *check_button,
 			     NautilusFile *file,
 			     GnomeVFSFilePermissions permission)
 {
-	guint toggled_signal_id;
+	gulong toggled_signal_id;
 
 	toggled_signal_id = g_signal_connect (check_button, "toggled",
-      	              	    			G_CALLBACK (permissions_check_button_toggled),
-                            			file);
+					      G_CALLBACK (permissions_check_button_toggled),
+					      file);
 
 	/* Load up the check_button with data we'll need when updating its state. */
-        g_object_set_data (G_OBJECT (check_button), 
-        		     "toggled_signal_id", 
-        		     GINT_TO_POINTER (toggled_signal_id));
-        g_object_set_data (G_OBJECT (check_button), 
-        		     "permission", 
-        		     GINT_TO_POINTER (permission));
+        g_object_set_data (G_OBJECT (check_button), "toggled_signal_id", 
+			   GUINT_TO_POINTER (toggled_signal_id));
+        g_object_set_data (G_OBJECT (check_button), "permission", 
+			   GINT_TO_POINTER (permission));
 	
 	/* Set initial state. */
         update_permissions_check_button_state (check_button, file);
 
         /* Update state later if file changes. */
-	g_signal_connect_object (file,
-				 "changed",
+	g_signal_connect_object (file, "changed",
 				 G_CALLBACK (update_permissions_check_button_state),
 				 check_button, G_CONNECT_SWAPPED);
 }
@@ -2206,6 +2158,9 @@ create_properties_window (StartupData *startup_data)
 {
 	FMPropertiesWindow *window;
 	GList *attributes;
+	GtkWidget *vbox;
+	GtkWidget *hbox;
+	GtkWidget *button;
 
 	window = FM_PROPERTIES_WINDOW (gtk_widget_new (fm_properties_window_get_type (), NULL));
 
@@ -2240,16 +2195,21 @@ create_properties_window (StartupData *startup_data)
 
 	/* React to future property changes and file deletions. */
 	window->details->file_changed_handler_id =
-		g_signal_connect_swapped (window->details->target_file,
-					  "changed",
-					  G_CALLBACK (properties_window_file_changed_callback),
-					  window);
+		g_signal_connect_object (window->details->target_file, "changed",
+					 G_CALLBACK (properties_window_file_changed_callback),
+					 window, G_CONNECT_SWAPPED);
+
+	/* Create box for notebook and button box. */
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (vbox);
+	gtk_container_add (GTK_CONTAINER (window), 
+			   GTK_WIDGET (vbox));
 
 	/* Create the notebook tabs. */
 	window->details->notebook = GTK_NOTEBOOK (gtk_notebook_new ());
 	gtk_widget_show (GTK_WIDGET (window->details->notebook));
-	gtk_container_add (GTK_CONTAINER (window), 
-			   GTK_WIDGET (window->details->notebook));
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (window->details->notebook),
+			    TRUE, TRUE, 0);
 
 	/* Create the pages. */
 	create_basic_page (window);
@@ -2261,6 +2221,23 @@ create_properties_window (StartupData *startup_data)
 	if (should_show_permissions (window)) {
 		create_permissions_page (window);
 	}
+	
+	/* Create box for close button. */
+	hbox = gtk_hbutton_box_new ();
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (hbox),
+			    FALSE, TRUE, 5);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox),
+				   GTK_BUTTONBOX_END);  
+
+	/* Create close button. */
+	button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+ 	gtk_widget_show (button);
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (button),
+			    FALSE, TRUE, 0);
+	g_signal_connect_swapped (button, "clicked",
+				  G_CALLBACK (gtk_widget_destroy),
+				  window);
 
 	return window;
 }
@@ -2415,10 +2392,8 @@ fm_properties_window_present (NautilusFile *original_file, FMDirectoryView *dire
 	 */
 	
 	g_hash_table_insert (pending_files, target_file, target_file);
-	g_signal_connect (directory_view,
-			    "destroy",
-			    G_CALLBACK (directory_view_destroyed_callback),
-			    startup_data);
+	g_signal_connect (directory_view, "destroy",
+			  G_CALLBACK (directory_view_destroyed_callback), startup_data);
 
 	parent_window = gtk_widget_get_ancestor (GTK_WIDGET (directory_view), GTK_TYPE_WINDOW);
 	eel_timed_wait_start
@@ -2471,7 +2446,7 @@ real_destroy (GtkObject *object)
 		window->details->update_directory_contents_timeout_id = 0;
 	}
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
 static void
@@ -2484,7 +2459,7 @@ real_finalize (GObject *object)
 	g_free (window->details->pending_name);
 	g_free (window->details);
 
-	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 /* icon selection callback to set the image of the file object to the selected file */
@@ -2506,7 +2481,8 @@ set_icon_callback (const char* icon_path, FMPropertiesWindow *properties_window)
 
 		/* re-enable the property window's clear image button */ 
 		gtk_widget_set_sensitive (properties_window->details->remove_image_button, TRUE);
-	}	
+	} else {
+	}
 }
 
 
@@ -2540,4 +2516,17 @@ remove_image_button_callback (GtkWidget *widget, FMPropertiesWindow *properties_
 	gtk_widget_set_sensitive (widget, FALSE);
 }
 
+static void
+fm_properties_window_class_init (FMPropertiesWindowClass *class)
+{
+	G_OBJECT_CLASS (class)->finalize = real_finalize;
+	GTK_OBJECT_CLASS (class)->destroy = real_destroy;
+}
 
+static void
+fm_properties_window_instance_init (FMPropertiesWindow *window)
+{
+	window->details = g_new0 (FMPropertiesWindowDetails, 1);
+
+	eel_gtk_window_set_up_close_accelerator (GTK_WINDOW (window));
+}
