@@ -60,6 +60,7 @@
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-metafile-factory.h>
 #include <libnautilus-private/nautilus-sound.h>
+#include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-private/nautilus-volume-monitor.h>
 #include <libnautilus-private/nautilus-authn-manager.h>
@@ -69,9 +70,9 @@
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 
-#define FACTORY_IID	     "OAFIID:nautilus_factory:bd1e1862-92d7-4391-963e-37583f0daef3"
-#define SEARCH_LIST_VIEW_IID "OAFIID:nautilus_file_manager_search_list_view:b186e381-198e-43cf-9c46-60b6bb35db0b"
-#define SHELL_IID	     "OAFIID:nautilus_shell:cd5183b2-3913-4b74-9b8e-10528b0de08d"
+#define FACTORY_IID	     "OAFIID:Nautilus_Factory"
+#define SEARCH_LIST_VIEW_IID "OAFIID:Nautilus_File_Manager_Search_List_View"
+#define SHELL_IID	     "OAFIID:Nautilus_Shell"
 
 /* Keeps track of the one and only desktop window. */
 static NautilusDesktopWindow *nautilus_application_desktop_window;
@@ -141,12 +142,12 @@ nautilus_application_instance_init (NautilusApplication *application)
 	application->undo_manager = nautilus_undo_manager_new ();
 
 	/* Watch for volume mounts so we can restore open windows */
-	g_signal_connect (nautilus_volume_monitor_get (), "volume_mounted",
-			  G_CALLBACK (volume_mounted_callback), application);
+	g_signal_connect_object (nautilus_volume_monitor_get (), "volume_mounted",
+				 G_CALLBACK (volume_mounted_callback), application, 0);
 
 	/* Watch for volume unmounts so we can close open windows */
-	g_signal_connect (nautilus_volume_monitor_get (), "volume_unmounted",
-			  G_CALLBACK (volume_unmounted_callback), application);
+	g_signal_connect_object (nautilus_volume_monitor_get (), "volume_unmounted",
+				 G_CALLBACK (volume_unmounted_callback), application, 0);
 }
 
 NautilusApplication *
@@ -413,7 +414,7 @@ nautilus_application_startup (NautilusApplication *application,
 	/* Start up the factory. */
 	while (TRUE) {
 		/* Try to register the file manager view factory. */
-		result = bonobo_activation_active_server_register
+		result = nautilus_bonobo_activation_register_for_display
 			(FACTORY_IID, BONOBO_OBJREF (application));
 
 		switch (result) {
@@ -575,11 +576,20 @@ nautilus_application_startup (NautilusApplication *application,
 static void
 nautilus_application_create_desktop_window (NautilusApplication *application)
 {
+	static gboolean create_in_progress = FALSE;
+
 	g_return_if_fail (nautilus_application_desktop_window == NULL);
 	g_return_if_fail (NAUTILUS_IS_APPLICATION (application));
 
+	if (create_in_progress) {
+		return;
+	}
+
+	create_in_progress = TRUE;
+
 	nautilus_application_desktop_window = nautilus_desktop_window_new (application);
-	gtk_widget_show (GTK_WIDGET (nautilus_application_desktop_window));
+
+	create_in_progress = FALSE;
 }
 
 void
@@ -634,16 +644,14 @@ nautilus_application_create_window (NautilusApplication *application)
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
 	
 	window = NAUTILUS_WINDOW (gtk_widget_new (nautilus_window_get_type (),
-						  "app", G_OBJECT (application),
+						  "app", application,
 						  "app_id", "nautilus", NULL));
 	
-	g_signal_connect (window, 
-			  "delete_event", G_CALLBACK (nautilus_window_delete_event_callback),
-			  NULL);
+	g_signal_connect (window, "delete_event",
+			  G_CALLBACK (nautilus_window_delete_event_callback), NULL);
 
-	g_signal_connect (window,
-			  "destroy", G_CALLBACK (nautilus_application_destroyed_window),
-			  application);
+	g_signal_connect_object (window, "destroy",
+				 G_CALLBACK (nautilus_application_destroyed_window), application, 0);
 
 	nautilus_application_window_list = g_list_prepend (nautilus_application_window_list, window);
 
@@ -693,7 +701,7 @@ desktop_changed_callback (gpointer user_data)
  * presented is: ~/.nautilus/first-time-flag.
  *
  * Another alternative could be to use preferences to store this flag
- * However, there because of bug 1229 this is not yet possible.
+ * However, there because of bug 41229 this is not yet possible.
  *
  * Also, for debugging purposes, it is convenient to have just one file
  * to kill in order to test the startup druid:
@@ -873,12 +881,10 @@ init_session (void)
 	client = gnome_master_client ();
 
 	g_signal_connect (client, "save_yourself",
-			    (GtkSignalFunc) save_session,
-			    NULL);
+			  G_CALLBACK (save_session), NULL);
 	
 	g_signal_connect (client, "die",
-			    (GtkSignalFunc) removed_from_session,
-			    NULL);
+			  G_CALLBACK (removed_from_session), NULL);
 	
 	eel_preferences_add_callback
 		(NAUTILUS_PREFERENCES_ADD_TO_SESSION,
