@@ -49,6 +49,7 @@
 #include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkpaned.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
@@ -83,7 +84,7 @@ struct NautilusSidebarDetails {
 	gboolean has_buttons;
 	char *uri;
 	NautilusFile *file;
-	gulong file_changed_connection;
+	guint file_changed_connection;
 	char *default_background_color;
 	char *default_background_image;
 	int selected_index;
@@ -131,6 +132,10 @@ static void     background_metadata_changed_callback   (NautilusSidebar  *sideba
 #define SIDEBAR_MINIMUM_WIDTH 1
 #define SIDEBAR_MINIMUM_HEIGHT 400
 
+/* Some auto-updated values */
+static int      sidebar_width_auto_value = SIDEBAR_MINIMUM_WIDTH;
+static gboolean confirm_trash_auto_value = TRUE;
+
 enum {
 	LOCATION_CHANGED,
 	LAST_SIGNAL
@@ -166,9 +171,6 @@ typedef enum {
 	TABS_PART
 } SidebarPart;
 
-static gboolean confirm_trash_auto_value;
-
-
 EEL_CLASS_BOILERPLATE (NautilusSidebar, nautilus_sidebar, GTK_TYPE_EVENT_BOX)
 
 /* initializing the class object by installing the operations we override */
@@ -205,9 +207,6 @@ nautilus_sidebar_class_init (GtkObjectClass *object_klass)
 		 NULL, NULL,
 		 g_cclosure_marshal_VOID__STRING,
 		 G_TYPE_NONE, 1, G_TYPE_STRING);
-
-	eel_preferences_add_auto_boolean (NAUTILUS_PREFERENCES_CONFIRM_TRASH,
-					       &confirm_trash_auto_value);
 }
 
 /* utility routine to allocate the box the holds the command buttons */
@@ -232,16 +231,30 @@ make_button_box (NautilusSidebar *sidebar)
 static void
 nautilus_sidebar_init (GtkObject *object)
 {
+	GtkWidget *widget;
+	static gboolean setup_autos = FALSE;
 	NautilusSidebar *sidebar;
-	GtkWidget* widget;
 	
 	sidebar = NAUTILUS_SIDEBAR (object);
 	widget = GTK_WIDGET (object);
 
 	sidebar->details = g_new0 (NautilusSidebarDetails, 1);
+
+	if (!setup_autos) {
+		setup_autos = TRUE;
+		eel_preferences_add_auto_integer (
+			NAUTILUS_PREFERENCES_SIDEBAR_WIDTH,
+			&sidebar_width_auto_value);
+
+		eel_preferences_add_auto_boolean (
+			NAUTILUS_PREFERENCES_CONFIRM_TRASH,
+			&confirm_trash_auto_value);
+	}
 	
-	/* set the minimum size of the sidebar */
-	gtk_widget_set_size_request (widget, SIDEBAR_MINIMUM_WIDTH, SIDEBAR_MINIMUM_HEIGHT);
+	/* set the requested size of the sidebar */
+	gtk_widget_set_size_request (widget, sidebar_width_auto_value,
+				     SIDEBAR_MINIMUM_HEIGHT);
+	sidebar->details->old_width = sidebar_width_auto_value;
 
 	/* load the default background from the current theme */
 	nautilus_sidebar_read_theme(sidebar);
@@ -278,8 +291,6 @@ nautilus_sidebar_init (GtkObject *object)
 	gtk_box_pack_end (GTK_BOX (sidebar->details->container),
 			  GTK_WIDGET (sidebar->details->sidebar_tabs),
 			  FALSE, FALSE, 0);
-
-	sidebar->details->old_width = widget->allocation.width;
 	
 	/* allocate and install the panel tabs */
   	sidebar->details->notebook = GTK_NOTEBOOK (gtk_notebook_new ());
@@ -331,8 +342,6 @@ nautilus_sidebar_finalize (GObject *object)
 	sidebar = NAUTILUS_SIDEBAR (object);
 
 	if (sidebar->details->file != NULL) {
-		g_signal_handler_disconnect (sidebar->details->file, 
-					     sidebar->details->file_changed_connection);
 		nautilus_file_monitor_remove (sidebar->details->file, sidebar);
 		nautilus_file_unref (sidebar->details->file);
 	}
@@ -498,17 +507,13 @@ sidebar_for_each_sidebar_panel (const char *name,
 	gtk_widget_show (menu_item);
 	g_object_set_data (G_OBJECT (menu_item), "user_data", data->sidebar);
 	gtk_menu_shell_append (GTK_MENU_SHELL (data->menu), menu_item);
-	g_signal_connect_data (menu_item,
-			       "activate",
+	g_signal_connect_data (menu_item, "activate",
 			       G_CALLBACK (toggle_sidebar_panel),
-			       g_strdup (iid),
-			       (GClosureNotify)g_free,
-			       0);
+			       g_strdup (iid), (GClosureNotify) g_free, 0);
 
 	g_object_set_data_full (G_OBJECT (menu_item),
 				"nautilus-sidebar/preference-key",
-				g_strdup (preference_key),
-				g_free);
+				g_strdup (preference_key), g_free);
 }
 
 /* utility routine to add a menu item for each potential sidebar panel */
@@ -563,8 +568,8 @@ nautilus_sidebar_create_context_menu (NautilusSidebar *sidebar)
  	gtk_widget_show (menu_item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
         gtk_widget_set_sensitive (menu_item, has_background);
-	g_signal_connect (menu_item, "activate",
-			    G_CALLBACK (reset_background_callback), sidebar);
+	g_signal_connect_object (menu_item, "activate",
+				 G_CALLBACK (reset_background_callback), sidebar, 0);
 
 	/* add a separator */
 	menu_item = gtk_menu_item_new ();
@@ -713,7 +718,7 @@ receive_dropped_uri_list (NautilusSidebar *sidebar,
 	GtkWindow *window;
 	
 	uris = g_strsplit (selection_data->data, "\r\n", 0);
-	exactly_one = uris[0] != NULL && uris[1] == NULL;
+	exactly_one = uris[0] != NULL && (uris[1] == NULL || uris[1][0] == '\0');
 	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (sidebar)));
 	
 	switch (hit_test (sidebar, x, y)) {
@@ -933,8 +938,8 @@ nautilus_sidebar_add_panel (NautilusSidebar *sidebar, NautilusViewFrame *panel)
 
 	gtk_widget_show (label);
 	
-	g_signal_connect (panel, "view_loaded",
-			    G_CALLBACK (view_loaded_callback), sidebar);
+	g_signal_connect_object (panel, "view_loaded",
+				 G_CALLBACK (view_loaded_callback), sidebar, 0);
 	
 	gtk_notebook_append_page (GTK_NOTEBOOK (sidebar->details->notebook),
 				  GTK_WIDGET (panel), label);
@@ -1387,7 +1392,7 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 	/* Catch-all button after all the others. */
 	temp_button = gtk_button_new_with_label (_("Open with..."));
 	g_signal_connect (temp_button, "clicked",
-			    G_CALLBACK (open_with_callback), NULL);
+			  G_CALLBACK (open_with_callback), NULL);
 	g_object_set_data (G_OBJECT (temp_button), "user_data", sidebar);
 	gtk_widget_show (temp_button);
 	gtk_box_pack_start (GTK_BOX (sidebar->details->button_box),
@@ -1543,14 +1548,10 @@ nautilus_sidebar_update_appearance (NautilusSidebar *sidebar)
 	background = eel_get_widget_background (GTK_WIDGET (sidebar));
 	if (!sidebar->details->background_connected) {
 		sidebar->details->background_connected = TRUE;
-		g_signal_connect (background,
-				    "settings_changed",
-				    G_CALLBACK (background_settings_changed_callback),
-				    sidebar);
-		g_signal_connect (background,
-				    "reset",
-				    G_CALLBACK (background_reset_callback),
-				    sidebar);
+		g_signal_connect_object (background,"settings_changed",
+					 G_CALLBACK (background_settings_changed_callback), sidebar, 0);
+		g_signal_connect_object (background, "reset",
+					 G_CALLBACK (background_reset_callback), sidebar, 0);
 	}
 	
 	/* Set up the background color and image from the metadata. */
@@ -1639,7 +1640,6 @@ nautilus_sidebar_set_uri (NautilusSidebar *sidebar,
 	if (sidebar->details->file != NULL) {
 		g_signal_handler_disconnect (sidebar->details->file, 
 					     sidebar->details->file_changed_connection);
-
 		nautilus_file_monitor_remove (sidebar->details->file, sidebar);
 	}
 
@@ -1651,10 +1651,9 @@ nautilus_sidebar_set_uri (NautilusSidebar *sidebar,
 	sidebar->details->file = file;
 	
 	sidebar->details->file_changed_connection =
-		g_signal_connect_swapped (sidebar->details->file,
-					  "changed",
-					  G_CALLBACK (background_metadata_changed_callback),
-					  sidebar);
+		g_signal_connect_object (sidebar->details->file, "changed",
+					 G_CALLBACK (background_metadata_changed_callback),
+					 sidebar, G_CONNECT_SWAPPED);
 
 	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
 	nautilus_file_monitor_add (sidebar->details->file, sidebar, attributes);
@@ -1687,10 +1686,25 @@ nautilus_sidebar_size_allocate (GtkWidget *widget,
 	EEL_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
 	
 	/* remember the size if it changed */
-	
 	if (widget->allocation.width != sidebar->details->old_width) {
 		sidebar->details->old_width = widget->allocation.width;
  		eel_preferences_set_integer (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH,
 					     widget->allocation.width);
 	}	
 }
+
+void
+nautilus_sidebar_setup_width (NautilusSidebar *sidebar)
+{
+	GtkPaned *paned;
+
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR (sidebar));
+	g_return_if_fail (GTK_WIDGET (sidebar)->parent != NULL);
+
+	paned = GTK_PANED (GTK_WIDGET (sidebar)->parent);
+
+	/* FIXME bugzilla.gnome.org 41245: Saved in pixels instead of in %? */
+	/* FIXME bugzilla.gnome.org 41245: No reality check on the value? */
+	gtk_paned_set_position (paned, sidebar_width_auto_value);
+	sidebar->details->old_width = sidebar_width_auto_value;
+}
